==> owncloud-8.2.2p3.tgz: owncloud/apps/files/l10n/sk_SK.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Úložisko nie je dostupné",
    "Storage invalid" : "Úložisko nie je platné",
    "Unknown error" : "Neznáma chyba",
    "Could not move %s - File with this name already exists" : "Nie je možné presunúť %s - súbor s týmto menom už existuje",
    "Could not move %s" : "Nie je možné presunúť %s",
    "Permission denied" : "Prístup bol odmietnutý",
    "The target folder has been moved or deleted." : "Cieľový priečinok bol premiestnený alebo odstránený.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Názov %s už používa priečinok s%. Prosím zvoľte iný názov.",
    "Error when creating the file" : "Chyba pri vytváraní súboru",
    "Error when creating the folder" : "Chyba pri vytváraní priečinka",
    "Unable to set upload directory." : "Nemožno nastaviť priečinok pre nahrané súbory.",
    "Invalid Token" : "Neplatný token",
    "No file was uploaded. Unknown error" : "Žiaden súbor nebol nahraný. Neznáma chyba",
    "There is no error, the file uploaded with success" : "Nenastala žiadna chyba, súbor bol úspešne nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "The uploaded file was only partially uploaded" : "Ukladaný súbor sa nahral len čiastočne",
    "No file was uploaded" : "Žiadny súbor nebol uložený",
    "Missing a temporary folder" : "Chýba dočasný priečinok",
    "Failed to write to disk" : "Zápis na disk sa nepodaril",
    "Not enough storage available" : "Nedostatok dostupného úložného priestoru",
    "Upload failed. Could not find uploaded file" : "Nahrávanie zlyhalo. Nepodarilo sa nájsť nahrávaný súbor",
    "Upload failed. Could not get file info." : "Nahrávanie zlyhalo. Nepodarilo sa získať informácie o súbore.",
    "Invalid directory." : "Neplatný priečinok.",
    "Files" : "Súbory",
    "All files" : "Všetky súbory",
    "Favorites" : "Obľúbené",
    "Home" : "Domov",
    "Close" : "Zavrieť",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nemožno nahrať súbor {filename}, pretože je to priečinok, alebo má 0 bitov",
    "Total file size {size1} exceeds upload limit {size2}" : "Celková veľkosť súboru {size1} prekračuje upload limit {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nie je dostatok voľného miesta, chcete nahrať {size1} ale k dispozíciji je len {size2}",
    "Upload cancelled." : "Odosielanie je zrušené.",
    "Could not get result from server." : "Nepodarilo sa dostať výsledky zo servera.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Opustenie stránky zruší práve prebiehajúce odosielanie súboru.",
    "Actions" : "Akcie",
    "Download" : "Sťahovanie",
    "Rename" : "Premenovať",
    "Delete" : "Zmazať",
    "Details" : "Podrobnosti",
    "Select" : "Vybrať",
    "Pending" : "Čaká",
    "Unable to determine date" : "Nemožno určiť dátum",
    "This operation is forbidden" : "Táto operácia je zakázaná",
    "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
    "Error moving file." : "Chyba pri presune súboru.",
    "Error moving file" : "Chyba pri presúvaní súboru",
    "Error" : "Chyba",
    "{new_name} already exists" : "{new_name} už existuje",
    "Could not rename file" : "Nemožno premenovať súbor",
    "Could not create file" : "Nemožno vytvoriť súbor",
    "Could not create folder" : "Nemožno vytvoriť priečinok",
    "Error deleting file." : "Chyba pri mazaní súboru.",
    "No entries in this folder match '{filter}'" : "V tomto priečinku nič nezodpovedá '{filter}'",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "_%n folder_::_%n folders_" : ["%n priečinok","%n priečinky","%n priečinkov"],
    "_%n file_::_%n files_" : ["%n súbor","%n súbory","%n súborov"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "You don’t have permission to upload or create files here" : "Nemáte oprávnenie sem nahrávať alebo vytvoriť súbory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrávam %n súbor","Nahrávam %n súbory","Nahrávam %n súborov"],
    "New" : "Nový",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatné meno súboru.",
    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložisko používateľa {owner} je plné, súbory sa viac nedajú aktualizovať ani synchronizovať.",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložisko je plné. Súbory nemožno aktualizovať ani synchronizovať!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úloisko používateľa {owner} je takmer plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložisko je takmer plné ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["zodpovedá '{filter}'","zodpovedá '{filter}'","zodpovedá '{filter}'"],
    "Path" : "Cesta",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtov"],
    "Favorited" : "Pridané k obľúbeným",
    "Favorite" : "Obľúbené",
    "{newname} already exists" : "{newname} už existuje",
    "Upload" : "Nahrať",
    "Text file" : "Textový súbor",
    "New text file.txt" : "Nový text file.txt",
    "Folder" : "Priečinok",
    "New folder" : "Nový priečinok",
    "An error occurred while trying to update the tags" : "Pri pokuse o aktualizáciu štítkov došlo k chybe",
    "A new file or folder has been <strong>created</strong>" : "Nový súbor alebo priečinok bol <strong>vytvorený</strong>",
    "A file or folder has been <strong>changed</strong>" : "Súbor alebo priečinok bol <strong>zmenený</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Obmedzte upozornenia na vytvorenie a zmeny na vaše <strong>obľúbené súbory</strong> <em>(Len streamy)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Súbor alebo priečinok bol <strong>odstránený</strong>",
    "A file or folder has been <strong>restored</strong>" : "Súbor alebo priečinok bol <strong>obnovený</strong>",
    "You created %1$s" : "Vytvorili ste %1$s",
    "%2$s created %1$s" : "%2$s vytvoril %1$s",
    "%1$s was created in a public folder" : "%1$s vytvorený vo verejnom priečinku",
    "You changed %1$s" : "Zmenili ste %1$s",
    "%2$s changed %1$s" : "%2$s zmenil %1$s",
    "You deleted %1$s" : "Bol zmazaný %1$s",
    "%2$s deleted %1$s" : "%2$s zmazal %1$s",
    "You restored %1$s" : "Bol obnovený %1$s",
    "%2$s restored %1$s" : "%2$s obnovil %1$s",
    "%s could not be renamed as it has been deleted" : "%s nebolo možné premenovať, pretože bol zmazaný",
    "%s could not be renamed" : "%s nemohol byť premenovaný",
    "Upload (max. %s)" : "Nahrať (max. %s)",
    "File handling" : "Nastavenie správania sa k súborom",
    "Maximum upload size" : "Maximálna veľkosť odosielaného súboru",
    "max. possible: " : "najväčšie možné:",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "S PHP-FPM môže trvať do 5 minút, kým sa nastavenie po uložení prejaví.",
    "Save" : "Uložiť",
    "Can not be edited from here due to insufficient permissions." : "Úpravy nie sú možné z dôvodu nedostatočných oprávnení.",
    "Settings" : "Nastavenia",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Použite túto linku <a href=\"%s\" target=\"_blank\">pre prístup k vašim súborom cez WebDAV</a>",
    "Cancel upload" : "Zrušiť nahrávanie",
    "No files in here" : "Nie sú tu žiadne súbory",
    "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte zo svojimi zariadeniami!",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Select all" : "Vybrať všetko",
    "Upload too large" : "Nahrávanie je príliš veľké",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Súbory, ktoré sa snažíte nahrať, presahujú maximálnu veľkosť pre nahratie súborov na tento server.",
    "Files are being scanned, please wait." : "Čakajte, súbory sú prehľadávané.",
    "Currently scanning" : "Prehľadáva sa",
    "No favorites" : "Žiadne obľúbené",
    "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-9.0.3.tgz: owncloud/apps/files/l10n/sk_SK.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Úložisko nie je dostupné",
    "Storage invalid" : "Úložisko nie je platné",
    "Unknown error" : "Neznáma chyba",
    "Unable to set upload directory." : "Nemožno nastaviť priečinok pre nahrané súbory.",
    "Invalid Token" : "Neplatný token",
    "No file was uploaded. Unknown error" : "Žiaden súbor nebol nahraný. Neznáma chyba",
    "There is no error, the file uploaded with success" : "Nenastala žiadna chyba, súbor bol úspešne nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "The uploaded file was only partially uploaded" : "Ukladaný súbor sa nahral len čiastočne",
    "No file was uploaded" : "Žiadny súbor nebol uložený",
    "Missing a temporary folder" : "Chýba dočasný priečinok",
    "Failed to write to disk" : "Zápis na disk sa nepodaril",
    "Not enough storage available" : "Nedostatok dostupného úložného priestoru",
    "The target folder has been moved or deleted." : "Cieľový priečinok bol premiestnený alebo odstránený.",
    "Upload failed. Could not find uploaded file" : "Nahrávanie zlyhalo. Nepodarilo sa nájsť nahrávaný súbor",
    "Upload failed. Could not get file info." : "Nahrávanie zlyhalo. Nepodarilo sa získať informácie o súbore.",
    "Invalid directory." : "Neplatný priečinok.",
    "Files" : "Súbory",
    "All files" : "Všetky súbory",
    "Favorites" : "Obľúbené",
    "Home" : "Domov",
    "Close" : "Zavrieť",
    "Upload cancelled." : "Odosielanie je zrušené.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nemožno nahrať súbor {filename}, pretože je to priečinok, alebo má 0 bitov",
    "Total file size {size1} exceeds upload limit {size2}" : "Celková veľkosť súboru {size1} prekračuje upload limit {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nie je dostatok voľného miesta, chcete nahrať {size1} ale k dispozíciji je len {size2}",
    "Could not get result from server." : "Nepodarilo sa dostať výsledky zo servera.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Opustenie stránky zruší práve prebiehajúce odosielanie súboru.",
    "Actions" : "Akcie",
    "Download" : "Sťahovanie",
    "Rename" : "Premenovať",
    "Delete" : "Zmazať",
    "Disconnect storage" : "Odpojiť úložisko",
    "Unshare" : "Zrušiť zdieľanie",
    "Details" : "Podrobnosti",
    "Select" : "Vybrať",
    "Pending" : "Čaká",
    "Unable to determine date" : "Nemožno určiť dátum",
    "This operation is forbidden" : "Táto operácia je zakázaná",
    "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
    "No entries in this folder match '{filter}'" : "V tomto priečinku nič nezodpovedá '{filter}'",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "_%n folder_::_%n folders_" : ["%n priečinok","%n priečinky","%n priečinkov"],
    "_%n file_::_%n files_" : ["%n súbor","%n súbory","%n súborov"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "You don’t have permission to upload or create files here" : "Nemáte oprávnenie sem nahrávať alebo vytvoriť súbory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrávam %n súbor","Nahrávam %n súbory","Nahrávam %n súborov"],
    "New" : "Nový",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatné meno súboru.",
    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložisko používateľa {owner} je plné, súbory sa viac nedajú aktualizovať ani synchronizovať.",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložisko je plné. Súbory nemožno aktualizovať ani synchronizovať!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úloisko používateľa {owner} je takmer plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložisko je takmer plné ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["zodpovedá '{filter}'","zodpovedá '{filter}'","zodpovedá '{filter}'"],
    "Path" : "Cesta",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtov"],
    "Favorited" : "Pridané k obľúbeným",
    "Favorite" : "Obľúbené",
    "Folder" : "Priečinok",
    "New folder" : "Nový priečinok",
    "{newname} already exists" : "{newname} už existuje",
    "Upload" : "Nahrať",
    "An error occurred while trying to update the tags" : "Pri pokuse o aktualizáciu štítkov došlo k chybe",
    "A new file or folder has been <strong>created</strong>" : "Nový súbor alebo priečinok bol <strong>vytvorený</strong>",
    "A file or folder has been <strong>changed</strong>" : "Súbor alebo priečinok bol <strong>zmenený</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Obmedzte upozornenia na vytvorenie a zmeny na vaše <strong>obľúbené súbory</strong> <em>(Len streamy)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Súbor alebo priečinok bol <strong>odstránený</strong>",
    "A file or folder has been <strong>restored</strong>" : "Súbor alebo priečinok bol <strong>obnovený</strong>",
    "You created %1$s" : "Vytvorili ste %1$s",
    "%2$s created %1$s" : "%2$s vytvoril %1$s",
    "%1$s was created in a public folder" : "%1$s vytvorený vo verejnom priečinku",
    "You changed %1$s" : "Zmenili ste %1$s",
    "%2$s changed %1$s" : "%2$s zmenil %1$s",
    "You deleted %1$s" : "Bol zmazaný %1$s",
    "%2$s deleted %1$s" : "%2$s zmazal %1$s",
    "You restored %1$s" : "Bol obnovený %1$s",
    "%2$s restored %1$s" : "%2$s obnovil %1$s",
    "Upload (max. %s)" : "Nahrať (max. %s)",
    "File handling" : "Nastavenie správania sa k súborom",
    "Maximum upload size" : "Maximálna veľkosť odosielaného súboru",
    "max. possible: " : "najväčšie možné:",
    "Save" : "Uložiť",
    "Settings" : "Nastavenia",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Použite túto linku <a href=\"%s\" target=\"_blank\">pre prístup k vašim súborom cez WebDAV</a>",
    "Cancel upload" : "Zrušiť nahrávanie",
    "No files in here" : "Nie sú tu žiadne súbory",
    "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte zo svojimi zariadeniami!",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Select all" : "Vybrať všetko",
    "Upload too large" : "Nahrávanie je príliš veľké",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Súbory, ktoré sa snažíte nahrať, presahujú maximálnu veľkosť pre nahratie súborov na tento server.",
    "No favorites" : "Žiadne obľúbené",
    "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu",
    "Text file" : "Textový súbor",
    "New text file.txt" : "Nový text file.txt",
    "You changed %1$s" : "Zmenili ste %1$s",
    "You created %1$s" : "Vytvorili ste %1$s",
    "You deleted %1$s" : "Bol zmazaný %1$s",
    "You restored %1$s" : "Bol obnovený %1$s"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
